/*
 * Copyright (C) 2013-2014 Adrian Ulrich <adrian@blinkenlights.ch>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>. 
 */

package ch.blinkenlights.android.vanilla;

import android.content.Context;
import android.app.Activity;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ArrayAdapter;
import android.view.LayoutInflater;
import android.widget.TextView;

import android.graphics.Color;
import android.text.Spannable;
import android.text.SpannableStringBuilder;
import android.text.style.ForegroundColorSpan;
import android.text.Spannable;
import android.text.SpannableStringBuilder;

public class ShowQueueAdapter
	extends ArrayAdapter<Song>
	implements DragListView.DragAdapter {
	
	int mResource;
	int mHighlightRow;
	Context mContext;
	OnItemMovedListener mCallback;

	public ShowQueueAdapter(Context context, int resource) {
		super(context, resource);
		mResource = resource;
		mContext = context;
		mCallback = (OnItemMovedListener) context;
		mHighlightRow = -1;
	}

	/**
	 * Called if user moved a queue item
	 */
	public interface OnItemMovedListener {
		public void onItemMoved(int from, int to);
	}

	/**
	* Tells the adapter to highlight a specific row id
	* Set this to -1 to disable the feature
	*/
	public void highlightRow(int pos) {
		mHighlightRow = pos;
	}


	@Override
	public View getView(int position, View convertView, ViewGroup parent) {
		LayoutInflater inflater = ((Activity)mContext).getLayoutInflater();
		View row = inflater.inflate(mResource, parent, false);
		Song song = getItem(position);

		if (song != null) { // unlikely to fail but seems to happen in the wild.
			TextView target = ((TextView)row.findViewById(R.id.text));
			SpannableStringBuilder sb = new SpannableStringBuilder(song.title);
			sb.append('\n');
			sb.append(song.album+", "+song.artist);
			sb.setSpan(new ForegroundColorSpan(Color.GRAY), song.title.length() + 1, sb.length(), Spannable.SPAN_EXCLUSIVE_EXCLUSIVE);
			target.setText(sb);
		}

		View pmark = ((View)row.findViewById(R.id.playmark));
		pmark.setVisibility( ( position == mHighlightRow ? View.VISIBLE : View.INVISIBLE ));

		return row;
	}

	@Override
	public void remove(int position) {
		// not implemented
	}


	/**
	 * Moves a songs position in the queue
	 *
	 * @param from the index of the song to be moved
	 * @param to the new index position of the song
	 */
	@Override
	public void move(int from, int to) {
		mCallback.onItemMoved(from, to);
	}

}
